@@ -238,7 +238,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
-                    syncify_async_function(self.peerConnections[id].setRemoteDescription(answer))
+                    async def setremotedescription(pc):
+                        await self.peerConnections[id].setRemoteDescription(answer)
+
+                    syncify_async_function(setremotedescription)
 
 
         @self.sio.event
